==> google_translate_django4-0.2a0.tar.gz: google_translate_django4-0.2a0/setup.py <==
from distutils.core import setup
# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()
setup(
  name = 'google_translate_django4',
  packages = ['google_translate_django4'],   # Chose the same as "name"
  version = '0.2a',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'The working google translate module for Django version 4 and above',   # Give a short description about your library
  author = 'Serhii Hrekov',                   # Type in your name
  author_email = 'admin@broplanner.com',      # Type in your E-Mail
  url = 'https://github.com/webprice/google_translate_django4',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/webprice/google_translate_django4/archive/refs/tags/v_0.2a.tar.gz',    # I explain this later on
  long_description=long_description,
  long_description_content_type='text/markdown',

  keywords = ['Django translate', 'Django Google Translate', 'Google translate'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'django',
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
	'Programming Language :: Python :: 3.7',
	'Programming Language :: Python :: 3.8',
	'Programming Language :: Python :: 3.9',
  ],
)

==> google_translate_django4-0.3.tar.gz: google_translate_django4-0.3/setup.py <==
from distutils.core import setup
# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()
setup(
  name = 'google_translate_django4',
  packages = ['google_translate_django4'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'The working google translate module for Django version 4 and above',   # Give a short description about your library
  author = 'Serhii Hrekov',                   # Type in your name
  author_email = 'admin@broplanner.com',      # Type in your E-Mail
  url = 'https://github.com/webprice/google_translate_django4',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/webprice/google_translate_django4/archive/refs/tags/v_0.3.tar.gz',    # I explain this later on
  long_description=long_description,
  long_description_content_type='text/markdown',

  keywords = ['Django translate', 'Django Google Translate', 'Google translate'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'django',
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
	'Programming Language :: Python :: 3.7',
	'Programming Language :: Python :: 3.8',
	'Programming Language :: Python :: 3.9',
  ],
)
